#include <qpopupmenu.h>

#include "xtraydialog.h"
#include "trayicon.h"

#include "icons/loopback.xpm"

XTrayDialog::XTrayDialog( QWidget* parent, const char* name, bool modal, WFlags f )
	: QDialog( parent, name, modal, f )
{
	// Add your code
	requestRealClose = false;

	if (this->icon())
		trayIcon = new TrayIcon(QPixmap(*this->icon()), caption(), 0);
	else
		trayIcon = new TrayIcon(QPixmap(loopback_xpm), caption(), 0);

	trayVisibleMenu = new QPopupMenu();
	trayVisibleMenu->insertItem( "&Hide", this, SLOT(toggleVisible()) );
	trayVisibleMenu->insertItem( "&Close", this, SLOT(realClose()) );

	trayHiddenMenu = new QPopupMenu();
	trayHiddenMenu->insertItem( "&Open", this, SLOT(toggleVisible()) );
	trayHiddenMenu->insertItem( "&Close", this, SLOT(realClose()) );
	trayIcon->setPopup(trayHiddenMenu);

	QObject::connect(trayIcon,SIGNAL(doubleClicked(const QPoint&)),this,SLOT(toggleVisible()));

	trayIcon->show();
}

XTrayDialog::~XTrayDialog()
{
	trayIcon->hide();
}


void XTrayDialog::toggleVisible()
{
	if (isVisible())
	{
		hide();
	}
	else
	{
		showNormal();
	}
}

void XTrayDialog::realClose()
{
	requestRealClose = true;
	close();
}

void XTrayDialog::closeEvent(QCloseEvent *e)
{
	if (requestRealClose || (!trayIcon->supported()))
	{
		e->accept();
	}
	else
	{
		e->ignore();
		hide();
	}
}

void XTrayDialog::show()
{
	QDialog::show();
	trayIcon->setPopup(trayVisibleMenu);
}

void XTrayDialog::hide()
{
	QDialog::hide();
	trayIcon->setPopup(trayHiddenMenu);
}

void XTrayDialog::setIcon(QPixmap& pm)
{
	QDialog::setIcon(pm);
	trayIcon->setIcon(pm);
}

void XTrayDialog::setCaption (const QString& cap)
{
	QDialog::setCaption(cap);
	trayIcon->setToolTip(cap);
}
